@@ -56,6 +56,7 @@ struct _NmUnfsSetupPrivate
 /*    GtkWidget *debug_checkbox;*/
     
     gchar *env;
+    gboolean is_installed;
 };
 
 #define NM_UNFS_SETUP_GET_PRIVATE(o) \
@@ -72,6 +73,7 @@ static void nm_unfs_setup_enable_cb (GtkToggleButton *, gpointer);
 static void nm_unfs_setup_enable_options (NmUnfsSetup *, gboolean);
 static void nm_unfs_setup_manage_exported_paths (gpointer , gpointer );
 static void nm_unfs_setup_manage_allowed_ips (gpointer , gpointer );
+static gboolean nm_unfs_setup_is_installed (NmUnfsSetup *);
     
 G_DEFINE_TYPE (NmUnfsSetup, nm_unfs_setup, NM_CONN_WIDGET_TYPE)
 
@@ -142,6 +144,16 @@ nm_unfs_setup_is_enabled (NmUnfsSetup *self)
     return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(priv->checkbutton));
 }
 
+static gboolean
+nm_unfs_setup_is_installed (NmUnfsSetup *self)
+{
+    gint ret = system("sudo /usr/sbin/nm-unfs-setup isinstalled");
+    
+    g_debug("[%s] - Unfs is installed: %d", __FUNCTION__, ret);
+    
+    return ret;
+}
+
 static void
 nm_unfs_setup_create_widget (NmUnfsSetup *self)
 {
@@ -150,6 +162,18 @@ nm_unfs_setup_create_widget (NmUnfsSetup *self)
 
     priv = NM_UNFS_SETUP_GET_PRIVATE (self);
 
+    priv->is_installed = nm_unfs_setup_is_installed(self);
+
+    if (!priv->is_installed) {
+        GtkWidget *not_installed = gtk_label_new(_("NFS package is not installed"));
+#ifdef DIABLO
+        gtk_widget_set_size_request(not_installed, 359, -1);
+#endif
+        gtk_container_add(GTK_CONTAINER (self), not_installed);
+        return;      
+    }
+
+
     table = gtk_table_new (5, 2, TRUE);
 
     priv->checkbutton = gtk_check_button_new_with_label (_("enable"));
@@ -275,6 +299,10 @@ nm_unfs_setup_apply_changes (NmConnWidget *self)
     NmUnfsSetupPrivate *priv;
     priv = NM_UNFS_SETUP_GET_PRIVATE (unfssetup);
     
+    if (!priv->is_installed) {
+        return TRUE;
+    }
+    
     nm_unfs_setup_save_changes(unfssetup);
     
     if ( nm_unfs_setup_is_enabled(unfssetup) ) {
@@ -284,7 +312,7 @@ nm_unfs_setup_apply_changes (NmConnWidget *self)
         gsize length = 0;
         gchar **list = nm_file_dialog_get_list(NM_FILE_DIALOG(dialog), &length);
         
-        gchar *concat_paths = "";
+        gchar *concat_paths = g_strdup("");
         int i;
         for (i = 0; i < length; i++) {
             concat_paths = g_strconcat(concat_paths, " ", list[i], NULL);
@@ -294,7 +322,7 @@ nm_unfs_setup_apply_changes (NmConnWidget *self)
         length = 0;
         gchar **list2 = nm_file_dialog_get_list(NM_FILE_DIALOG(dialog2), &length);
         
-        gchar *concat_ips = "127.0.0.1,";
+        gchar *concat_ips = g_strdup("127.0.0.1,");
         for (i = 0; i < length; i++) {
             concat_ips = g_strconcat(concat_ips, list2[i], ",", NULL);
         }
@@ -365,6 +393,10 @@ nm_unfs_setup_save_changes (NmUnfsSetup *self)
 {
     NmUnfsSetupPrivate *priv = NM_UNFS_SETUP_GET_PRIVATE (self);
 
+    if (!priv->is_installed) {
+        return;
+    }
+
     NmSettings *settings = nm_settings_new();
   
     nm_settings_set_boolean (settings, priv->env, NM_UNFS_SETTINGS_GROUP,
@@ -407,6 +439,10 @@ void
 nm_unfs_setup_fill_widget(NmUnfsSetup *self)
 {
     NmUnfsSetupPrivate *priv = NM_UNFS_SETUP_GET_PRIVATE (self);
+
+    if (!priv->is_installed) {
+        return;
+    }
     
     if (strcmp(priv->env, nm_environment_manager_get_active())) {
 /*        g_debug("[%s] - %s is not the active environment", __FUNCTION__, priv->env);*/
