@@ -32,5 +32,7 @@ gboolean nm_usb_utils_unload (void);
 gboolean nm_usb_utils_put_in_host_mode (void);
 gboolean nm_usb_utils_is_host_mode (void);
 gboolean nm_usb_utils_put_in_otg_mode (void);
+gboolean nm_usb_utils_put_in_charging_only_mode (void);
+gboolean nm_usb_utils_is_charging_only (void);
 
 #endif
